@@ -4,8 +4,16 @@ use std::{
     rc::{Rc, Weak},
 };
 
+use swc_common::Span;
 use swc_html_ast::*;
 
+#[derive(Debug, Clone)]
+pub struct TokenAndInfo {
+    pub span: Span,
+    pub acknowledged: bool,
+    pub token: Token,
+}
+
 #[derive(Debug, Clone)]
 pub enum Data {
     Document(Document),
